package com.example.horses_xml_kotlin

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import org.xmlpull.v1.XmlPullParserException
import android.content.res.XmlResourceParser
import android.view.View
import android.widget.*

class MainActivity : AppCompatActivity() {

    val myList = arrayListOf<Horse>()  //bunch of horse objects

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val tvSire = findViewById<View>(R.id.tvSire) as TextView
        val tvTrainer = findViewById<View>(R.id.tvTrainer) as TextView
        val ivSilks = findViewById<View>(R.id.ivSilks) as ImageView

        try {
            val horsenames = ArrayList<String>()

            // access xml resource
            val parser = resources.getXml(R.xml.horseracing)
            var eventType = -1
            var myIndex = -1

            //loop through xml file
            while (eventType != XmlResourceParser.END_DOCUMENT) {
                if (eventType == XmlResourceParser.START_TAG) {
                    val tagName = parser.name
                    //Toast.makeText(getBaseContext(), tagName, Toast.LENGTH_LONG).show();
                    when (tagName) {
                        "element"  -> {
                            //starts a new horse
                            myList.add(Horse())
                            myIndex++
                        }
                        "horseJockey" -> {
                            parser.next()  //move to text
                            myList[myIndex].jockey = parser.text
                            //Toast.makeText(getBaseContext(), parser.getText(), Toast.LENGTH_LONG).show();
                            parser.next()   //move to end tag
                        }
                        "horseName" -> {
                            parser.next()
                            myList[myIndex].horseName = parser.text
                            horsenames.add(parser.text)
                            parser.next()
                        }
                        "horseRank" -> {
                            parser.next()
                            myList[myIndex].rank = Integer.parseInt(parser.text)
                            parser.next()
                        }
                        "horseRating" -> {
                            parser.next()
                            myList[myIndex].rating = java.lang.Double.parseDouble(parser.text)
                            parser.next()
                        }
                        "horseSilks" -> {
                            parser.next()  //move to text
                            myList[myIndex].silks = parser.text
                            parser.next()   //move to end tag
                        }
                        "horseSire" -> {
                            parser.next()  //move to text
                            myList[myIndex].sire = parser.text
                            parser.next()   //move to end tag
                        }
                        "horseTrainer" -> {
                            parser.next()  //move to text
                            myList[myIndex].trainer = parser.text
                            parser.next()   //move to end tag
                        }
                    } //end when
                } //end if start tag
                eventType = parser.next()
            } //end while loop through xml file


            //associate the full name with the listView
            val spHorse = findViewById<View>(R.id.spHorse) as Spinner
            val aaHorse = ArrayAdapter(this, android.R.layout.simple_spinner_item, horsenames)
            aaHorse.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item) // The drop down view
            spHorse.adapter = aaHorse

            spHorse.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
                override fun onItemSelected(adapterView: AdapterView<*>, view: View, i: Int, l: Long) {
                    tvSire.text = myList[i].sire
                    tvTrainer.text = myList[i].trainer

                    val iv_id = resources.getIdentifier(
                        myList[i].silks, "drawable",
                        packageName
                    )
                    ivSilks.setImageResource(iv_id)
                }

                override fun onNothingSelected(adapterView: AdapterView<*>) {}
            }

        } catch (e: XmlPullParserException) {
            Toast.makeText(baseContext, "Problem XML parsing problem", Toast.LENGTH_LONG).show()
        } catch (e: Exception) {
            Toast.makeText(baseContext, "Problem with file", Toast.LENGTH_LONG).show()
            e.printStackTrace()
        }

    }//end onCreate
} //end MainActivity
